==> haskell-pandoc-types-1.23.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-DdQZgf4FErf8aiJPYPPwhY
key:                  pandoc-types-1.23.1-DdQZgf4FErf8aiJPYPPwhY
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  07a89ba0848d9ae7ba1c5ae9f445b1b3
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-DdQZgf4FErf8aiJPYPPwhY
depends:
    QuickCheck-2.14.3-2FUI0ycZlrbG7BkVMiUKvc
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    ghc-prim-0.8.0 syb-0.7.2.4-IT59ozboet0H3NdhoNJGts text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.23.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-ux8hbPCvBO8neRyqNRN11
key:                  pandoc-types-1.23.1-ux8hbPCvBO8neRyqNRN11
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  3f1d33fea2b2147abee814a8a58f9391
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-ux8hbPCvBO8neRyqNRN11
depends:
    QuickCheck-2.14.3-2FUI0ycZlrbG7BkVMiUKvc
    aeson-2.1.2.1-3hy4hA3togDsVnwRqQAZI base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    ghc-prim-0.8.0 syb-0.7.2.4-IT59ozboet0H3NdhoNJGts text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
